<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk_SK" version="2.0">
<context>
    <name>RazorMainMenu</name>
    <message>
        <source>Leave</source>
        <translation>Opustiť</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <source>Razor Main Menu settings</source>
        <translation>Nastavenia Hlavného menu prostredia Razor</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation>Zobraziť text</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation>Text tlačidla</translation>
    </message>
    <message>
        <source>Menu file</source>
        <translation>Súbor menu</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Keyboard Shortcut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Click the button to record shortcut:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose menu file</source>
        <translation>Vybrať súbor menu</translation>
    </message>
    <message>
        <source>Menu files (*.menu)</source>
        <translation>Súbory menu (*.menu)</translation>
    </message>
</context>
</TS>